module.exports = {
  parser: 'babel-eslint',
  root: true,
  env: {
    browser: true,
    node: true,
    mocha: true,
    es6: true,
  },
  plugins: [
    'react',
    'mocha',
    'flowtype',
    'import',
  ],
  ecmaFeatures: {
    jsx: true,
  },
  extends: 'eslint:recommended',
  rules: {
    'array-bracket-spacing': ['error', 'never'],
    'arrow-spacing': 'error',
    'arrow-parens': 'error',
    'block-spacing': ['error', 'always'],
    'brace-style': 'error',
    'comma-dangle': ['error', 'always-multiline'],
    'comma-style': ['error', 'last'],
    'comma-spacing': ['error', {before: false, after: true}],
    'computed-property-spacing': ['error', 'never'],
    'consistent-this': ['error', 'self'],
    'consistent-return': 'error',
    'dot-notation': 'error',
    'dot-location': ['error', 'property'],
    'eqeqeq': ['error', 'smart'],
    'eol-last': 'error',
    'indent': ['error', 2, {SwitchCase: 1}],
    'jsx-quotes': ['error', 'prefer-double'],
    'key-spacing': 'error',
    'max-len': ['error', 120, 4],
    'new-cap': ['error', {capIsNew: true, newIsCap: true}],
    'no-console': 'error',
    'no-unused-expressions': 'error',
    'no-unused-vars': 'error',
    'no-shadow': 'error',
    'no-spaced-func': 'error',
    'no-multiple-empty-lines': 'error',
    'no-multi-spaces': 'error',
    'no-undef': 'error',
    'no-empty-pattern': 'error',
    'no-dupe-keys': 'error',
    'no-dupe-args': 'error',
    'no-duplicate-case': 'error',
    'no-cond-assign': 'error',
    'no-extra-semi': 'error',
    'no-extra-boolean-cast': 'error',
    'no-trailing-spaces': 'error',
    'no-unreachable': 'error',
    'no-unneeded-ternary': 'error',
    'no-useless-computed-key': 'error',
    'no-unsafe-finally': 'error',
    'no-process-exit': 'error',
    'no-var': 'error',
    'object-curly-spacing': ['error', 'never'],
    'one-var': ['error', 'never'],
    'operator-linebreak': ['error', 'after'],
    'padded-blocks': ['error', 'never'],
    'prefer-arrow-callback': 'error',
    'prefer-const': 'error',
    'prefer-template': 'error',
    'quotes': ['error', 'single', 'avoid-escape'],
    'semi': ['error', 'always'],
    'keyword-spacing': 'error',
    'space-before-blocks': ['error', 'always'],
    'space-before-function-paren': ['error', 'never'],
    'space-infix-ops': 'error',
    'space-unary-ops': ['error', { words: true, nonwords: false }],
    'spaced-comment': 'error',
    'yoda': 'error',
    'react/display-name': 'error',
    'react/jsx-boolean-value': ['error', 'always'],
    'react/jsx-closing-bracket-location': 'error',
    'react/jsx-curly-spacing': 'error',
    'react/jsx-equals-spacing': 'error',
    'react/jsx-first-prop-new-line': ['error', 'multiline'],
    'react/jsx-filename-extension': ['error', {extensions: ['.js']}],
    'react/jsx-key': 'error',
    'react/jsx-handler-names': 'error',
    'react/jsx-indent-props': ['error', 2],
    'react/jsx-indent': ['error', 2],
    'react/jsx-max-props-per-line': ['error', {maximum: 3}],
    'react/jsx-no-duplicate-props': 'error',
    'react/jsx-no-literals': 'error',
    'react/jsx-no-undef': 'error',
    'react/jsx-pascal-case': 'error',
    'react/jsx-space-before-closing': 'error',
    'react/jsx-uses-react': 'error',
    'react/jsx-uses-vars': 'error',
    'react/jsx-no-comment-textnodes': 'error',
    'react/no-danger': 'error',
    'react/no-deprecated': 'error',
    'react/no-did-mount-set-state': 'error',
    'react/no-did-update-set-state': 'error',
    'react/no-direct-mutation-state': 'error',
    'react/no-multi-comp': 'error',
    'react/no-render-return-value': 'error',
    'react/no-is-mounted': 'error',
    'react/no-unknown-property': 'error',
    'react/prop-types': 'error',
    'react/prefer-es6-class': 'error',
    'react/react-in-jsx-scope': 'error',
    'react/require-render-return': 'error',
    'react/self-closing-comp': 'error',
    'react/sort-comp': 'error',
    'react/sort-prop-types': 'error',
    'react/jsx-wrap-multilines': 'error',
    'react/no-find-dom-node': 'error',
    'mocha/handle-done-callback': 'error',
    'mocha/no-exclusive-tests': 'error',
    'mocha/no-global-tests': 'error',
    'mocha/no-pending-tests': 'error',
    'mocha/no-skipped-tests': 'error',
    'mocha/no-sibling-hooks': 'error',
    'flowtype/require-valid-file-annotation': ['error', 'always'],
    'import/default': 'error',
    'import/export': 'error',
    'import/extensions': ['error', {
      'json': 'always',
      'html': 'always',
      'server': 'always',
      'css': 'always',
      'png': 'always',
      'jpg': 'always',
      'svg': 'always',
    }],
    'import/imports-first': 'error',
    'import/named': 'error',
    'import/namespace': 'error',
    'import/newline-after-import': 'error',
    'import/no-amd': 'error',
    'import/no-deprecated': 'error',
    'import/no-duplicates': 'error',
    'import/no-mutable-exports': 'error',
    'import/no-named-as-default': 'error',
    'import/no-named-as-default-member': 'error',
    'import/no-namespace': 'error',
    'import/no-restricted-paths': 'error',
    'import/order': 'error',
    'import/prefer-default-export': 'error',

    'no-case-declarations': 'off',
    'strict': 'off',
    'no-magic-numbers': 'off',
    'camelcase': 'off',
    'no-underscore-dangle': 'off',
    'handle-callback-err': 'off',
    'mocha/no-hooks': 'off',
    'mocha/no-mocha-arrows': 'off',
    'mocha/no-synchronous-tests': 'off',
    'mocha/valid-suite-description': 'off',
    'mocha/valid-test-description': 'off',
    'react/jsx-no-bind': 'off',
    'react/jsx-no-target-blank': 'off',
    'react/jsx-sort-props': 'off',
    'react/no-set-state': 'off',
    'react/no-string-refs': 'off',
    'react/forbid-prop-types': 'off',
    'react/prefer-stateless-function': 'off',
    'react/require-optimization': 'off',
    'flowtype/require-parameter-type': 'off',
    'flowtype/require-return-type': 'off',
    'flowtype/space-after-type-colon': 'off',
    'flowtype/space-before-type-colon': 'off',
    'flowtype/type-id-match': 'off',
    'flowtype/define-flow-type': 'off',
    'flowtype/use-flow-type': 'off',
    'import/no-extraneous-dependencies': 'off',
    'import/no-nodejs-modules': 'off',
    'import/no-unresolved': 'off',
    'import/no-commonjs': 'off',
  },
  settings: {
    'import/ignore': [
      'node_modules', // Mostly CommonJS (ignored by default).
      '\.(json|svg|html)$', // Can't parse.
    ],
  },
};
