// @flow weak

import React, {PropTypes} from 'react';
import {css, withStyles} from 'withStyles';
import Button from './Button';

const PageFooter = (props) => {
  const {
    maintainerName,
    maintainerUrl,
    repositoryName,
    repositoryUrl,
    styles,
  } = props;

  return (
    <footer {...css(styles.root)}>
      <span {...css(styles.rootOwner)}>
        <Button component="a" href={repositoryUrl}>
          {repositoryName}
        </Button>
        {' is maintained by '}
        <Button component="a" href={maintainerUrl}>
          {maintainerName}
        </Button>
        {'.'}
      </span>
      <span {...css(styles.rootCredits)}>
        {'This page was generated by '}
        <Button component="a" href="https://pages.github.com">
          {'GitHub Pages'}
        </Button>
        {' using the '}
        <Button component="a" href="https://github.com/jasonlong/cayman-theme">
          {'Cayman theme'}
        </Button>
        {' by '}
        <Button component="a" href="https://twitter.com/jasonlong">
          {'Jason Long'}
        </Button>
        {'.'}
      </span>
    </footer>
  );
};

PageFooter.propTypes = {
  maintainerName: PropTypes.string.isRequired,
  maintainerUrl: PropTypes.string.isRequired,
  repositoryName: PropTypes.string.isRequired,
  repositoryUrl: PropTypes.string.isRequired,
  styles: PropTypes.object.isRequired,
};

export default withStyles(({media}) => ({
  root: {
    paddingTop: 32,
    marginTop: 32,
    borderTop: 'solid 1px #e4e6e7',
    fontSize: 14,
    [media.large]: {
      fontSize: 16,
    },
  },
  rootOwner: {
    display: 'block',
    fontWeight: 'bold',
  },
  rootCredits: {
    color: '#819198',
  },
}))(PageFooter);
